pecos.qeccs.instruction\_parent\_class
======================================

.. automodule:: pecos.qeccs.instruction_parent_class











   .. rubric:: Classes

   .. autosummary::

      LogicalInstruction
